@@ -1,4 +1,4 @@
-﻿/* Date: 230727 Ver: 10.5B  Update also in plbwebbasic.js */
+﻿/* Date: 250122 Ver: 10.7A  Update also in plbwebbasic.js */
 
 $.widget("ui.timespinner", $.ui.spinner, {
     options: {
@@ -169,6 +169,10 @@ function PlbTabC(ci) {
     var pb = $("#" + ci.id);
 
     pb.tabs();
+    
+    if (plbWebNamespace != undefined) {
+	    pb.on("tabsbeforeactivate", function (event, ui) { plbWebNamespace.PlbWebBasic.prototype.AddPlbTabEv(event, ui, ci.id, 4) });
+        }
 }
 
 function PlbSlide(ci) {
